summaryrefslogtreecommitdiffstats
path: root/kdesktop/bgmanager.cc
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:43:14 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:43:14 -0600
commit79b21d47bce1ee428affc97534cd8b257232a871 (patch)
tree0df1fa0109d9f2bcef932eda8b5c25b2e06669ed /kdesktop/bgmanager.cc
parent9a898d493f493adbc404f7223043c85f3817472b (diff)
downloadtdebase-79b21d47bce1ee428affc97534cd8b257232a871.tar.gz
tdebase-79b21d47bce1ee428affc97534cd8b257232a871.zip
Rename KGlobal, KProcess, and KClipboard to avoid conflicts with KDE4
Diffstat (limited to 'kdesktop/bgmanager.cc')
-rw-r--r--kdesktop/bgmanager.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdesktop/bgmanager.cc b/kdesktop/bgmanager.cc
index aa0aa598d..e15c6aabe 100644
--- a/kdesktop/bgmanager.cc
+++ b/kdesktop/bgmanager.cc
@@ -78,7 +78,7 @@ KBackgroundManager::KBackgroundManager(TQWidget *desktop, KWinModule* twinModule
m_Cache.resize( 1 );
m_Serial = 0; m_Hash = 0;
- m_pConfig = KGlobal::config();
+ m_pConfig = TDEGlobal::config();
m_bExport = m_bCommon = m_bInit = false;
m_pKwinmodule = twinModule;
m_pPixmapServer = new KPixmapServer();
@@ -136,7 +136,7 @@ KBackgroundManager::~KBackgroundManager()
for (unsigned i=0; i<m_Renderer.size(); i++)
delete m_Renderer[i];
//delete m_pConfig; Very bad idea, this is KGlobal::config !
delete m_pPixmapServer;
delete m_pTimer;
@@ -136,7 +136,7 @@ KBackgroundManager::~KBackgroundManager()
for (unsigned i=0; i<m_Renderer.size(); i++)
delete m_Renderer[i];
- //delete m_pConfig; Very bad idea, this is KGlobal::config !
+ //delete m_pConfig; Very bad idea, this is TDEGlobal::config !
delete m_pPixmapServer;
delete m_pTimer;